RetryUtil class

Utility class for retrying operations with exponential backoff.

Constructors

RetryUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

logger LLMLogger
Logger used to report retries.
getter/setter pair

Static Methods

executeWithRetry<T>({required Future<T> operation(), RetryConfig? config, bool isRetryable(Object error)?, void onRetry(int attempt, Object error, Duration delay)?}) Future<T>
Execute a function with retry logic.